@@ -1,36 +1,22 @@
 /*
- *  devicelisting.cpp
+ *  SPDX-FileCopyrightText: 2009 David Hubner <hubnerd@ntlworld.com>
  *
- *  Copyright (C) 2009 David Hubner <hubnerd@ntlworld.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #include "devicelisting.h"
 
-//Solid
+// Solid
 #include <solid/devicenotifier.h>
 
 #include <QContextMenuEvent>
 #include <QMenu>
 
-//Local
+// Local
+#include "devinfo.h"
 #include "infopanel.h"
 #include "soldevicetypes.h"
-#include "devinfo.h"
 #include "solidhelper.h"
 //#include "nicsignals.h"
 
@@ -39,23 +25,20 @@ DeviceListing::DeviceListing(QWidget *parent, InfoPanel *info, DevInfoPlugin *st
     , iPanel(info)
     , status(stat)
 {
-//     // Check nic changes
-//    nicSig = new NicSignals();
-//    connect(nicSig,SIGNAL(nicActivatedOrDisconnected()),this,SLOT(networkingChangedSlot()));
-//
+    //     // Check nic changes
+    //    nicSig = new NicSignals();
+    //    connect(nicSig,SIGNAL(nicActivatedOrDisconnected()),this,SLOT(networkingChangedSlot()));
+    //
     // Check if selection changed
     connect(this, &DeviceListing::currentItemChanged, this, &DeviceListing::currentItemChangedSlot);
 
     // Check if item is added
-    connect(Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceAdded, this,
-            &DeviceListing::deviceAddedSlot);
+    connect(Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceAdded, this, &DeviceListing::deviceAddedSlot);
 
     // Check if item is removed
-    connect(Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceRemoved, this,
-            &DeviceListing::deviceRemovedSlot);
+    connect(Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceRemoved, this, &DeviceListing::deviceRemovedSlot);
 
-    setWhatsThis(i18nc("Device Listing Whats This",
-                       "Shows all the devices that are currently listed."));
+    setWhatsThis(i18nc("Device Listing Whats This", "Shows all the devices that are currently listed."));
 
     createMenuActions();
     setHeaderLabels(QStringList(i18n("Devices")));
@@ -65,7 +48,7 @@ DeviceListing::DeviceListing(QWidget *parent, InfoPanel *info, DevInfoPlugin *st
 
 DeviceListing::~DeviceListing()
 {
-    //delete nicSig;
+    // delete nicSig;
     clear();
 }
 
@@ -125,7 +108,7 @@ void DeviceListing::populateListing(const show showStatus)
 
     clear();
 
-    for (unsigned int i = 0; i < (sizeof(needHardware)/sizeof(Solid::DeviceInterface::Type)); i++) {
+    for (unsigned int i = 0; i < (sizeof(needHardware) / sizeof(Solid::DeviceInterface::Type)); i++) {
         QTreeWidgetItem *tmpDevice = createListItems(needHardware[i]);
         deviceMap[needHardware[i]] = static_cast<SolDevice *>(tmpDevice);
 
@@ -234,3 +217,5 @@ void DeviceListing::showRelevantDevicesSlot()
 {
     populateListing(RELEVANT);
 }
+
+#include "moc_devicelisting.cpp"
